@@ -4,6 +4,7 @@ from typing import Union, Optional
 from dataclasses import dataclass, field
 from statsig.statsig_errors import StatsigValueError
 from statsig.statsig_user import StatsigUser
+from statsig.utils import to_raw_dict_or_none
 
 
 @dataclass
@@ -26,7 +27,8 @@ class StatsigEvent:
         if self.event_name is None or self.event_name == "":
             raise StatsigValueError(
                 'StatsigEvent.event_name must be a valid str')
-        if self.value is not None and not isinstance(self.value, str) and not isinstance(self.value, float) and not isinstance(self.value, int):
+        if self.value is not None and not isinstance(self.value, str) and not isinstance(
+                self.value, float) and not isinstance(self.value, int):
             raise StatsigValueError(
                 'StatsigEvent.value must be a str, float, or int')
 
@@ -35,7 +37,7 @@ class StatsigEvent:
             'user': None if self.user is None else self.user.to_dict(False),
             'eventName': self.event_name,
             'value': self.value,
-            'metadata': self.metadata,
+            'metadata': to_raw_dict_or_none(self.metadata),
             'secondaryExposures': self._secondary_exposures,
             'time': self._time
         }
